Package: arrayhelpers
Type: Package
Title: Convenience Functions for Arrays
Description: Some convenient functions to work with arrays.
Maintainer: Claudia Beleites <Claudia.Beleites@chemometrix.eu>
Authors@R: c(
    person("Claudia",   "Beleites",  role = c("aut","cre"), email = "Claudia.Beleites@chemometrix.eu")
    )
Version: 1.1-2
Date: 2026-07-24
License: GPL
LazyLoad: yes
Imports: methods, utils, svUnit
URL: http://arrayhelpers.r-forge.r-project.org/
Encoding: UTF-8
Collate: 'unittestdata.R' 'arrayhelpers.R' 'apply.R' 'array2df.R'
        'array2vec.R' 'arrayhelpers-package.R' 'colSums.R'
        'countrows.R' 'delold.R' 'dropdimnames.R' 'ensuredim.R'
        'groupsum.R' 'init.R' 'makeNd.R' 'ndim.R' 'numericindices.R'
        'restoredim.R' 'rowsum.R' 'slice.R' 'stack.R' 'ta.R'
        'unittests.R'
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-24 14:41:13 UTC; cb
Author: Claudia Beleites [aut, cre]
Repository: CRAN
Date/Publication: 2026-07-24 18:50:02 UTC
