# Generated by roxygen2: do not edit by hand

export("slice<-")
export(array2df)
export(array2vec)
export(arrayhelpers.unittest)
export(colMeans.AsIs)
export(colSums.AsIs)
export(delold)
export(drop1d)
export(dropdimnames)
export(ensuredim)
export(groupsum)
export(lon)
export(makeNd)
export(ndim)
export(numericindex)
export(restoredim)
export(rowMeans.AsIs)
export(rowSums.AsIs)
export(slice)
export(ta)
export(vec2array)
exportMethods(colMeans)
exportMethods(colSums)
exportMethods(rowMeans)
exportMethods(rowSums)
exportMethods(rowsum)
import(methods)
import(svUnit)
importFrom(utils,head)
importFrom(utils,tail)
